@@ -22,21 +22,18 @@ class TestCcp001v1(SDKBaseTest):
     def test_description(self):
         # flake8: noqa
         expected = 'All patients with COVID Questionnaire completed Date < 7 days ago and >  5 days ago.'
-        self.assertEqual(expected, Ccp001v1.description)
+        self.assertEqual(expected, Ccp001v1._meta.description)
 
     def test_information(self):
         # flake8: noqa
         expected = 'https://canvas-medical.zendesk.com/hc/en-us/articles/360059084173-COVID-19-Risk-Assessment-Follow-Up-Protocol'
-        self.assertEqual(expected, Ccp001v1.information)
+        self.assertEqual(expected, Ccp001v1._meta.information)
 
     def test_change_types(self):
-        result = Ccp001v1.compute_on_change_types
+        result = Ccp001v1._meta.compute_on_change_types
         expected = ['interview']
         self.assertEqual(expected, result)
 
-    def test_revision(self):
-        self.assertEqual('2020-04-03v1', Ccp001v1.revision())
-
     def test___init__(self):
         start = arrow.get('2019-03-20 13:24:56')
         end = arrow.get('2020-03-20 13:24:56')
@@ -84,7 +81,7 @@ class TestCcp001v1(SDKBaseTest):
             assert expected == str(result), f'{hour} -> {result}'
 
     @patch(
-        'protocols.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
+        'canvas_workflow_kit.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
         new_callable=PropertyMock)
     def test_interview(self, anchor_time):
         anchor_time.return_value = arrow.get('2020-03-20T09:00:00+00:00')
@@ -135,7 +132,7 @@ class TestCcp001v1(SDKBaseTest):
         self.assertEqual(134, result['id'])
 
     @patch(
-        'protocols.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
+        'canvas_workflow_kit.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
         new_callable=PropertyMock)
     def test_in_initial_population(self, anchor_time):
         anchor_time.return_value = arrow.get('2020-03-20T09:00:00+00:00')
@@ -172,7 +169,7 @@ class TestCcp001v1(SDKBaseTest):
         self.assertTrue(tested.in_initial_population())
 
     @patch(
-        'protocols.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
+        'canvas_workflow_kit.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
         new_callable=PropertyMock)
     def test_in_denominator(self, anchor_time):
         anchor_time.return_value = arrow.get('2020-03-20T09:00:00+00:00')
@@ -260,10 +257,10 @@ class TestCcp001v1(SDKBaseTest):
         self.assertEqual(expected, result)
 
     @patch(
-        'protocols.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.interview',
+        'canvas_workflow_kit.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.interview',
         new_callable=PropertyMock)
     @patch(
-        'protocols.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
+        'canvas_workflow_kit.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
         new_callable=PropertyMock)
     def test_in_numerator(self, anchor_time, interview):
         anchor_time.return_value = arrow.get('2020-03-20T09:00:00+00:00')
@@ -358,9 +355,9 @@ class TestCcp001v1(SDKBaseTest):
         ]
         self.assertEqual(expected, tested.rationales_for_inclusion_in_numerator)
 
-    @patch('protocols.builtin_cqms.ccp001v1_symptomatic_surveillance.arrow.utcnow')
+    @patch('canvas_workflow_kit.builtin_cqms.ccp001v1_symptomatic_surveillance.arrow.utcnow')
     @patch(
-        'protocols.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
+        'canvas_workflow_kit.builtin_cqms.ccp001v1_symptomatic_surveillance.Ccp001v1.anchor_time',
         new_callable=PropertyMock)
     def test_compute_results(self, anchor_time, utcnow):
         utcnow.return_value = arrow.get('2020-03-20 13:24:56')
