@@ -1088,7 +1088,7 @@ class TestBillingLineItemRecordSet(TestCase):
         tested = BillingLineItemRecordSet([])
         self.assertIsInstance(tested, BillingLineItemRecordSet)
         self.assertEqual(['cpt', 'hcpcs', 'snomedct'], tested.VALID_SYSTEMS)
-        self.assertEqual('created', tested.DATE_FIELD)
+        self.assertEqual('datetimeOfService', tested.DATE_FIELD)
         self.assertEqual('billing_line_items', tested.PATIENT_FIELD)
         self.assertEqual('patient__key', tested.API_KEY_FIELD)
         self.assertEqual('billingLineItems', tested.API_UPDATE_FIELD)
